@@ -273,7 +273,7 @@ plugin_couchdb_contacts (EPlugin *epl, EConfigHookItemFactoryData *data)
 	} else {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ui->user_db_button), TRUE);
 		if (!property)
-			e_source_set_property (ui->source, "couchdb_instance", "system");
+			e_source_set_property (ui->source, "couchdb_instance", "user");
 		gtk_widget_set_sensitive (ui->remote_db_entry, FALSE);
 	}
 
